﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace ShowHot.ComponentOrganizing
{
    public partial class DatePickerComponent : UserControl
    {

        #region Members

        public enum ComponentStates
        {
            HideUp = 0,
            ExtraUp = 1,
            Main = 2,
            ExtraDown = 3,
            HideDown = 4
        }

        //상태를 기억하는 변수
        public ComponentStates State
        {
            get { return _state; }
            set
            {
                _state = value;
                setState();
                setHeight();
            }
        }
        private ComponentStates _state;

        //날짜를 기억하는 변수
        public DateTime Date
        {
            get { return _date; }
            set
            {
                _date = value;
                setDate();
            }
        }
        private DateTime _date;

        #endregion Members

        #region Events

        /// <summary>
        /// 모션이 중단된 이벤트
        /// </summary>
        public event EventHandler MotionFinished;

        #endregion Events

        #region Constructors

        public DatePickerComponent()
        {
            InitializeComponent();

            // 초기화
            Date = DateTime.Now;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// TextBlock 에 날짜를 설정
        /// </summary>
        private void setDate()
        {
            tbYear.Text = Date.Year.ToString();
            tbMonth.Text = Date.Month.ToString();
            tbDay.Text = Date.Day.ToString();
        }

        /// <summary>
        /// 자신의 스테이트에 맞는 크기 스토리보드 실행
        /// </summary>
        private void setState()
        {
            switch (State)
            {
                case ComponentStates.HideUp:
                case ComponentStates.HideDown:
                    VisualStateManager.GoToState(this, "Hide", false);
                    Cursor = Cursors.Arrow;
                    break;
                case ComponentStates.ExtraUp:
                case ComponentStates.ExtraDown:
                    VisualStateManager.GoToState(this, "Extra", false);
                    Cursor = Cursors.Hand;
                    break;
                case ComponentStates.Main:
                    VisualStateManager.GoToState(this, "SuperStar", false);
                    Cursor = Cursors.Arrow;
                    break;
            }
        }

        /// <summary>
        /// 자신의 스테이트에 맞는 위치 스토리 보드
        /// </summary>
        private void setHeight()
        {
            VisualStateManager.GoToState(this, State.ToString(), false);
        }


        #endregion Methods

        #region EventHandlers

        private void Storyboard_Completed(object sender, EventArgs e)
        {
            OnMotionFinished();
        }

        #endregion EventHandlers


        #region EventFires

        private void OnMotionFinished()
        {
            if (MotionFinished == null)
                return;

            MotionFinished(this, null);
        }

        #endregion EventFires
    }
}
